@@ -28,12 +28,18 @@ use log4rs::config::{Appender, Root};
 use log4rs::Config;
 use std::sync::mpsc::Sender;
 use std::sync::Arc;
-use std::thread;
 use std::thread::JoinHandle;
+use std::{panic, process, thread};
 use tokio::io;
 
 #[tokio::main]
 async fn main() -> io::Result<()> {
+    // terminate on panic
+    panic::set_hook(Box::new(|info| {
+        eprintln!("Exiting on panic: {}", info);
+        process::exit(0x1);
+    }));
+
     let mut benchmark_config = BenchmarkConfig::from_command_line().map_err(|e| {
         println!("Failed to process parameters. Exiting.");
         e
@@ -43,10 +49,8 @@ async fn main() -> io::Result<()> {
 
     info!("Starting with configuration {}", benchmark_config);
 
-    let (reporter_task, batch_metric_sender) = create_async_metrics_channel(
-        benchmark_config.reporters.clone(),
-        benchmark_config.continuous,
-    );
+    let (reporter_task, batch_metric_sender) =
+        create_async_metrics_channel(&benchmark_config.reporters, benchmark_config.continuous);
     let bench_session = benchmark_config.new_bench_session();
 
     for batch in bench_session {
@@ -76,7 +80,7 @@ fn shutdown(reporter_task: JoinHandle<()>, batch_metric_sender: Sender<BenchRunM
 }
 
 fn create_async_metrics_channel(
-    metric_reporters: Vec<Arc<Box<dyn ExternalMetricsServiceReporter + Send + Sync + 'static>>>,
+    metric_reporters: &[Arc<dyn ExternalMetricsServiceReporter + Send + Sync + 'static>],
     continuous: bool,
 ) -> (JoinHandle<()>, Sender<BenchRunMetrics>) {
     // We need to report metrics in a separate threads,
@@ -84,6 +88,7 @@ fn create_async_metrics_channel(
     // had `async` APIs.
     // We can replace it with `tokio::sync::mpsc` and `tokio::spawn` at any time
     let (sender, receiver) = std::sync::mpsc::channel();
+    let metric_reporters = metric_reporters.to_owned();
     let reporter_task = thread::spawn(move || {
         while let Ok(stats) = receiver.recv() {
             // broadcast to all metrics reporters
@@ -96,7 +101,7 @@ fn create_async_metrics_channel(
         // for continuous runs we don't want to reset metrics
         // to avoid saw-like graphs
         if !continuous {
-            for reporter in &metric_reporters {
+            for reporter in metric_reporters {
                 reporter.reset_metrics();
             }
         }
